@@ -23,19 +23,19 @@
 #include "kdeversion.h"
 #include <config-kdelibs4support.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QFile>
+#include <QDir>
+#include <QFile>
 #include <QSessionManager>
 #include <QStyleFactory>
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <QWidget>
 #include <QIcon>
 #include <QPointer>
-#include <QtCore/QList>
+#include <QList>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
-#include <QtCore/QMetaType>
+#include <QMetaType>
 
 #include "kauthorized.h"
 #include "k4aboutdata.h"
@@ -49,7 +49,6 @@
 #include "klocalizedstring.h"
 #include "ksessionmanager.h"
 #include "ktoolinvocation.h"
-#include "kgesturemap_p.h"
 #include "kurl.h"
 #include "kmessage.h"
 #include "kmessageboxmessagehandler.h"
@@ -109,7 +108,7 @@
 #include <QActionEvent>
 #include <kcomponentdata.h>
 
-KApplication *KApplication::KApp = 0L;
+KApplication *KApplication::KApp = nullptr;
 
 #if HAVE_X11
 static Atom atom_DesktopWindow;
@@ -123,7 +122,7 @@ template class QList<KSessionManager *>;
 void KApplication_init_windows();
 #endif
 
-static KApplicationPrivate *kapp_priv = 0;
+static KApplicationPrivate *kapp_priv = nullptr;
 
 /*
   Private data to make keeping binary compatibility easier
@@ -136,12 +135,12 @@ public:
         , componentData(cName)
         , session_save(false)
 #if HAVE_X11
-        , oldIceIOErrorHandler(0)
-        , oldXErrorHandler(0)
-        , oldXIOErrorHandler(0)
+        , oldIceIOErrorHandler(nullptr)
+        , oldXErrorHandler(nullptr)
+        , oldXIOErrorHandler(nullptr)
         , isX11(false)
 #endif
-        , pSessionConfig(0)
+        , pSessionConfig(nullptr)
         , bSessionManagement(true)
     {
         kapp_priv = this;
@@ -152,12 +151,12 @@ public:
         , componentData(cData)
         , session_save(false)
 #if HAVE_X11
-        , oldIceIOErrorHandler(0)
-        , oldXErrorHandler(0)
-        , oldXIOErrorHandler(0)
+        , oldIceIOErrorHandler(nullptr)
+        , oldXErrorHandler(nullptr)
+        , oldXIOErrorHandler(nullptr)
         , isX11(false)
 #endif
-        , pSessionConfig(0)
+        , pSessionConfig(nullptr)
         , bSessionManagement(true)
     {
         kapp_priv = this;
@@ -168,12 +167,12 @@ public:
         , componentData(KCmdLineArgs::aboutData())
         , session_save(false)
 #if HAVE_X11
-        , oldIceIOErrorHandler(0)
-        , oldXErrorHandler(0)
-        , oldXIOErrorHandler(0)
+        , oldIceIOErrorHandler(nullptr)
+        , oldXErrorHandler(nullptr)
+        , oldXIOErrorHandler(nullptr)
         , isX11(false)
 #endif
-        , pSessionConfig(0)
+        , pSessionConfig(nullptr)
         , bSessionManagement(true)
     {
         kapp_priv = this;
@@ -235,7 +234,7 @@ extern "C" {
 }
 #endif
 
-static QList< QPointer< QWidget > > *x11Filter = 0;
+static QList< QPointer< QWidget > > *x11Filter = nullptr;
 
 /**
    * Installs a handler for the SIGPIPE signal. It is thrown when you write to
@@ -251,7 +250,7 @@ static void installSigpipeHandler()
     act.sa_handler = SIG_IGN;
     sigemptyset(&act.sa_mask);
     act.sa_flags = 0;
-    sigaction(SIGPIPE, &act, 0);
+    sigaction(SIGPIPE, &act, nullptr);
 #endif
 }
 
@@ -283,18 +282,18 @@ void KApplication::removeX11EventFilter(const QWidget *filter)
             it.hasNext();
         ) {
         QWidget *w = it.next().data();
-        if (w == filter || w == NULL) {
+        if (w == filter || w == nullptr) {
             it.remove();
         }
     }
     if (x11Filter->isEmpty()) {
         delete x11Filter;
-        x11Filter = 0;
+        x11Filter = nullptr;
     }
 }
 
 #if HAVE_X11
-static SmcConn mySmcConnection = 0;
+static SmcConn mySmcConnection = nullptr;
 #else
 // FIXME(E): Implement for Qt Embedded
 // Possibly "steal" XFree86's libSM?
@@ -344,12 +343,7 @@ int KApplicationPrivate::xErrhandler(Display *dpy, void *err_)
 
 void KApplicationPrivate::iceIOErrorHandler(_IceConn *conn)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-http://thread.gmane.org/gmane.comp.kde.devel.frameworks/1122
-    emit kapp->aboutToQuit();
-#endif
-
-    if (oldIceIOErrorHandler != NULL) {
+    if (oldIceIOErrorHandler != nullptr) {
         (*oldIceIOErrorHandler)(conn);
     }
     exit(1);
@@ -379,7 +373,8 @@ void KApplicationPrivate::init(bool GUIenabled)
 
     parseCommandLine();
 
-    QApplication::setDesktopSettingsAware(false);
+    QGuiApplication::setDesktopSettingsAware(false);
+    QGuiApplication::setFallbackSessionManagementEnabled(false);
 
 #if HAVE_X11
     isX11 = (QGuiApplication::platformName() == QStringLiteral("xcb"));
@@ -411,7 +406,7 @@ void KApplicationPrivate::init(bool GUIenabled)
     // sanity checking, to make sure we've connected
     extern void qDBusBindToApplication();
     qDBusBindToApplication();
-    QDBusConnectionInterface *bus = 0;
+    QDBusConnectionInterface *bus = nullptr;
     if (!QDBusConnection::sessionBus().isConnected() || !(bus = QDBusConnection::sessionBus().interface())) {
         kFatal(240) << "Session bus not found" << endl <<
                     "To circumvent this problem try the following command (with Linux and bash)" << endl <<
@@ -465,13 +460,17 @@ void KApplicationPrivate::init(bool GUIenabled)
     // Trigger initial settings
     KGlobalSettings::self()->activate();
 
-    KMessage::setMessageHandler(new KMessageBoxMessageHandler(0));
-
-    KGestureMap::self()->installEventFilterOnMe(q);
+    KMessage::setMessageHandler(new KMessageBoxMessageHandler(nullptr));
 
     q->connect(KToolInvocation::self(), SIGNAL(kapplication_hook(QStringList&,QByteArray&)),
                q, SLOT(_k_slot_KToolInvocation_hook(QStringList&,QByteArray&)));
 
+    q->connect(q, SIGNAL(commitDataRequest(QSessionManager&)),
+               q, SLOT(commitData(QSessionManager&)));
+    q->connect(q, SIGNAL(saveStateRequest(QSessionManager&)),
+               q, SLOT(saveState(QSessionManager&)));
+
+
 #ifdef Q_OS_MAC
     // This is a QSystemTrayIcon instead of K* because we can't be sure q is a QWidget
     QSystemTrayIcon *trayIcon; //krazy:exclude=qclasses
@@ -577,11 +576,13 @@ void KApplication::commitData(QSessionManager &sm)
                 continue;
             }
 
+            // leave KMainWindows alone because they are handled by KMWSessionManager
             if (!w->isHidden() && !w->inherits("KMainWindow")) {
                 QCloseEvent e;
                 sendEvent(w, &e);
                 if (!e.isAccepted()) {
-                    break;    //canceled
+                    canceled = true;
+                    break;
                 }
 
                 donelist.append(w);
@@ -597,10 +598,14 @@ void KApplication::commitData(QSessionManager &sm)
     } else {
         sm.setRestartHint(QSessionManager::RestartIfRunning);
     }
+
+    if (canceled) {
+        sm.cancel();
+    }
     d->session_save = false;
 }
 
-#if HAVE_X11
+#if HAVE_X11 && QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 static void checkRestartVersion(QSessionManager &sm)
 {
     Display *dpy = QX11Info::display();
@@ -714,6 +719,8 @@ void KApplication::saveState(QSessionManager &sm)
     if (canceled) {
         sm.cancel();
     }
+#else
+    Q_UNUSED(sm);
 #endif
     d->session_save = false;
 }
@@ -792,23 +799,23 @@ KApplication::~KApplication()
 {
 #if HAVE_X11
     if (d->isX11) {
-        if (d->oldXErrorHandler != NULL) {
+        if (d->oldXErrorHandler != nullptr) {
             XSetErrorHandler(d->oldXErrorHandler);
         }
-        if (d->oldXIOErrorHandler != NULL) {
+        if (d->oldXIOErrorHandler != nullptr) {
             XSetIOErrorHandler(d->oldXIOErrorHandler);
         }
-        if (d->oldIceIOErrorHandler != NULL) {
+        if (d->oldIceIOErrorHandler != nullptr) {
             IceSetIOErrorHandler(d->oldIceIOErrorHandler);
         }
     }
 #endif
 
     delete d;
-    KApp = 0;
+    KApp = nullptr;
 
 #if HAVE_X11
-    mySmcConnection = 0;
+    mySmcConnection = nullptr;
 #endif
 }
 
@@ -988,4 +995,3 @@ void KApplicationPrivate::_k_slot_KToolInvocation_hook(QStringList &envs, QByteA
 }
 
 #include "moc_kapplication.cpp"
-
